===========
Awasu Tools
===========

``awasu_tools`` is a set of classes and utilities to help write `Awasu <https://awasu.com>`_ extensions.

The main features are:

- ``Feed`` and ``FeedItem`` classes, for generating feed XML.
- ``ConfigFile``, for reading Awasu INI files.
- logging services.

A tutorial is available `here <https://awasu.com/weblog/writing-extensions/>`_.
